@@ -5,40 +5,38 @@ see templateexporter.py.
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from __future__ import print_function, absolute_import
 
-import io
-import os
-import copy
 import collections
+import copy
 import datetime
+import os
+import sys
+from typing import Optional
 
 import nbformat
-
-from traitlets.config.configurable import LoggingConfigurable
+from traitlets import Bool, HasTraits, List, TraitError, Unicode
 from traitlets.config import Config
-from traitlets import HasTraits, Unicode, List, TraitError
+from traitlets.config.configurable import LoggingConfigurable
 from traitlets.utils.importstring import import_item
-from ipython_genutils import text, py3compat
 
 
 class ResourcesDict(collections.defaultdict):
     def __missing__(self, key):
-        return ''
+        return ""
 
 
 class FilenameExtension(Unicode):
     """A trait for filename extensions."""
 
-    default_value = u''
-    info_text = 'a filename extension, beginning with a dot'
+    default_value = ""
+    info_text = "a filename extension, beginning with a dot"
 
     def validate(self, obj, value):
         # cast to proper unicode
-        value = super(FilenameExtension, self).validate(obj, value)
+        value = super().validate(obj, value)
 
         # check that it starts with a dot
-        if value and not value.startswith('.'):
+        if value and not value.startswith("."):
             msg = "FileExtension trait '{}' does not begin with a dot: {!r}"
             raise TraitError(msg.format(self.name, value))
 
@@ -52,41 +50,50 @@ class Exporter(LoggingConfigurable):
     accompanying resources dict.
     """
 
-    file_extension = FilenameExtension('.txt',
+    enabled = Bool(True, help="Disable this exporter (and any exporters inherited from it).").tag(
+        config=True
+    )
+
+    file_extension = FilenameExtension(
         help="Extension of the file that should be written to disk"
     ).tag(config=True)
 
+    optimistic_validation = Bool(
+        False,
+        help="Reduces the number of validation steps so that it only occurs after all preprocesors have run.",
+    ).tag(config=True)
+
     # MIME type of the result file, for HTTP response headers.
     # This is *not* a traitlet, because we want to be able to access it from
     # the class, not just on instances.
-    output_mimetype = ''
+    output_mimetype = ""
 
     # Should this converter be accessible from the notebook front-end?
     # If so, should be a friendly name to display (and possibly translated).
     export_from_notebook = None
 
-    #Configurability, allows the user to easily add filters and preprocessors.
-    preprocessors = List(
-        help="""List of preprocessors, by name or namespace, to enable."""
-    ).tag(config=True)
+    # Configurability, allows the user to easily add filters and preprocessors.
+    preprocessors = List(help="""List of preprocessors, by name or namespace, to enable.""").tag(
+        config=True
+    )
 
     _preprocessors = List()
 
-    default_preprocessors = List([
-                                  'nbconvert.preprocessors.TagRemovePreprocessor',
-                                  'nbconvert.preprocessors.RegexRemovePreprocessor',
-                                  'nbconvert.preprocessors.ClearOutputPreprocessor',
-                                  'nbconvert.preprocessors.ExecutePreprocessor',
-                                  'nbconvert.preprocessors.coalesce_streams',
-                                  'nbconvert.preprocessors.SVG2PDFPreprocessor',
-                                  'nbconvert.preprocessors.CSSHTMLHeaderPreprocessor',
-                                  'nbconvert.preprocessors.LatexPreprocessor',
-                                  'nbconvert.preprocessors.HighlightMagicsPreprocessor',
-                                  'nbconvert.preprocessors.ExtractOutputPreprocessor',
-                                  'nbconvert.preprocessors.ClearMetadataPreprocessor',
-                              ],
+    default_preprocessors = List(
+        [
+            "nbconvert.preprocessors.TagRemovePreprocessor",
+            "nbconvert.preprocessors.RegexRemovePreprocessor",
+            "nbconvert.preprocessors.ClearOutputPreprocessor",
+            "nbconvert.preprocessors.ExecutePreprocessor",
+            "nbconvert.preprocessors.coalesce_streams",
+            "nbconvert.preprocessors.SVG2PDFPreprocessor",
+            "nbconvert.preprocessors.LatexPreprocessor",
+            "nbconvert.preprocessors.HighlightMagicsPreprocessor",
+            "nbconvert.preprocessors.ExtractOutputPreprocessor",
+            "nbconvert.preprocessors.ClearMetadataPreprocessor",
+        ],
         help="""List of preprocessors available by default, by name, namespace,
-        instance, or type."""
+        instance, or type.""",
     ).tag(config=True)
 
     def __init__(self, config=None, **kw):
@@ -95,7 +102,7 @@ class Exporter(LoggingConfigurable):
 
         Parameters
         ----------
-        config : :class:`~traitlets.config.Config`
+        config : ``traitlets.config.Config``
             User configuration instance.
         `**kw`
             Additional keyword arguments passed to parent __init__
@@ -105,10 +112,10 @@ class Exporter(LoggingConfigurable):
         if config:
             with_default_config.merge(config)
 
-        super(Exporter, self).__init__(config=with_default_config, **kw)
+        super().__init__(config=with_default_config, **kw)
 
         self._init_preprocessors()
-
+        self._nb_metadata = {}
 
     @property
     def default_config(self):
@@ -121,27 +128,31 @@ class Exporter(LoggingConfigurable):
         Parameters
         ----------
         nb : :class:`~nbformat.NotebookNode`
-          Notebook node (dict-like with attr-access)
+            Notebook node (dict-like with attr-access)
         resources : dict
-          Additional resources that can be accessed read/write by
-          preprocessors and filters.
+            Additional resources that can be accessed read/write by
+            preprocessors and filters.
         `**kw`
-          Ignored
+            Ignored
 
         """
         nb_copy = copy.deepcopy(nb)
         resources = self._init_resources(resources)
 
-        if 'language' in nb['metadata']:
-            resources['language'] = nb['metadata']['language'].lower()
+        if "language" in nb["metadata"]:
+            resources["language"] = nb["metadata"]["language"].lower()
 
         # Preprocess
         nb_copy, resources = self._preprocess(nb_copy, resources)
-
+        notebook_name = ""
+        if resources is not None:
+            name = resources.get("metadata", {}).get("name", "")
+            path = resources.get("metadata", {}).get("path", "")
+            notebook_name = os.path.join(path, name)
+        self._nb_metadata[notebook_name] = nb_copy.metadata
         return nb_copy, resources
 
-
-    def from_filename(self, filename, resources=None, **kw):
+    def from_filename(self, filename: str, resources: Optional[dict] = None, **kw):
         """
         Convert a notebook from a notebook file.
 
@@ -150,35 +161,33 @@ class Exporter(LoggingConfigurable):
         filename : str
             Full filename of the notebook file to open and convert.
         resources : dict
-          Additional resources that can be accessed read/write by
-          preprocessors and filters.
+            Additional resources that can be accessed read/write by
+            preprocessors and filters.
         `**kw`
-          Ignored
+            Ignored
 
         """
-        # Convert full filename string to unicode
-        # In python 2.7.x if filename comes as unicode string,
-        # just skip converting it.
-        if isinstance(filename, str):
-           filename = py3compat.str_to_unicode(filename)
-
         # Pull the metadata from the filesystem.
         if resources is None:
             resources = ResourcesDict()
-        if not 'metadata' in resources or resources['metadata'] == '':
-            resources['metadata'] = ResourcesDict()
+        if "metadata" not in resources or resources["metadata"] == "":
+            resources["metadata"] = ResourcesDict()
         path, basename = os.path.split(filename)
         notebook_name = os.path.splitext(basename)[0]
-        resources['metadata']['name'] = notebook_name
-        resources['metadata']['path'] = path
+        resources["metadata"]["name"] = notebook_name
+        resources["metadata"]["path"] = path
 
         modified_date = datetime.datetime.fromtimestamp(os.path.getmtime(filename))
-        resources['metadata']['modified_date'] = modified_date.strftime(text.date_format)
+        # datetime.strftime date format for ipython
+        if sys.platform == "win32":
+            date_format = "%B %d, %Y"
+        else:
+            date_format = "%B %-d, %Y"
+        resources["metadata"]["modified_date"] = modified_date.strftime(date_format)
 
-        with io.open(filename, encoding='utf-8') as f:
+        with open(filename, encoding="utf-8") as f:
             return self.from_file(f, resources=resources, **kw)
 
-
     def from_file(self, file_stream, resources=None, **kw):
         """
         Convert a notebook from a notebook file.
@@ -188,44 +197,48 @@ class Exporter(LoggingConfigurable):
         file_stream : file-like object
             Notebook file-like object to convert.
         resources : dict
-          Additional resources that can be accessed read/write by
-          preprocessors and filters.
+            Additional resources that can be accessed read/write by
+            preprocessors and filters.
         `**kw`
-          Ignored
+            Ignored
 
         """
-        return self.from_notebook_node(nbformat.read(file_stream, as_version=4), resources=resources, **kw)
-
+        return self.from_notebook_node(
+            nbformat.read(file_stream, as_version=4), resources=resources, **kw
+        )
 
     def register_preprocessor(self, preprocessor, enabled=False):
         """
         Register a preprocessor.
         Preprocessors are classes that act upon the notebook before it is
-        passed into the Jinja templating engine.  preprocessors are also
+        passed into the Jinja templating engine. Preprocessors are also
         capable of passing additional information to the Jinja
         templating engine.
 
         Parameters
         ----------
-        preprocessor : :class:`~nbconvert.preprocessors.Preprocessor`
+        preprocessor : `nbconvert.preprocessors.Preprocessor`
             A dotted module name, a type, or an instance
         enabled : bool
             Mark the preprocessor as enabled
 
         """
         if preprocessor is None:
-            raise TypeError('preprocessor must not be None')
+            raise TypeError("preprocessor must not be None")
         isclass = isinstance(preprocessor, type)
         constructed = not isclass
 
         # Handle preprocessor's registration based on it's type
-        if constructed and isinstance(preprocessor, py3compat.string_types):
+        if constructed and isinstance(
+            preprocessor,
+            str,
+        ):
             # Preprocessor is a string, import the namespace and recursively call
             # this register_preprocessor method
             preprocessor_cls = import_item(preprocessor)
             return self.register_preprocessor(preprocessor_cls, enabled)
 
-        if constructed and hasattr(preprocessor, '__call__'):
+        if constructed and hasattr(preprocessor, "__call__"):  # noqa
             # Preprocessor is a function, no need to construct it.
             # Register and return the preprocessor.
             if enabled:
@@ -245,8 +258,9 @@ class Exporter(LoggingConfigurable):
         else:
             # Preprocessor is an instance of something without a __call__
             # attribute.
-            raise TypeError('preprocessor must be callable or an importable constructor, got %r' % preprocessor)
-
+            raise TypeError(
+                "preprocessor must be callable or an importable constructor, got %r" % preprocessor
+            )
 
     def _init_preprocessors(self):
         """
@@ -263,10 +277,9 @@ class Exporter(LoggingConfigurable):
         for preprocessor in self.preprocessors:
             self.register_preprocessor(preprocessor, enabled=True)
 
-
     def _init_resources(self, resources):
 
-        #Make sure the resources dict is of ResourcesDict type.
+        # Make sure the resources dict is of ResourcesDict type.
         if resources is None:
             resources = ResourcesDict()
         if not isinstance(resources, ResourcesDict):
@@ -274,21 +287,27 @@ class Exporter(LoggingConfigurable):
             new_resources.update(resources)
             resources = new_resources
 
-        #Make sure the metadata extension exists in resources
-        if 'metadata' in resources:
-            if not isinstance(resources['metadata'], ResourcesDict):
+        # Make sure the metadata extension exists in resources
+        if "metadata" in resources:
+            if not isinstance(resources["metadata"], ResourcesDict):
                 new_metadata = ResourcesDict()
-                new_metadata.update(resources['metadata'])
-                resources['metadata'] = new_metadata
+                new_metadata.update(resources["metadata"])
+                resources["metadata"] = new_metadata
         else:
-            resources['metadata'] = ResourcesDict()
-            if not resources['metadata']['name']:
-                resources['metadata']['name'] = 'Notebook'
+            resources["metadata"] = ResourcesDict()
+            if not resources["metadata"]["name"]:
+                resources["metadata"]["name"] = "Notebook"
 
-        #Set the output extension
-        resources['output_extension'] = self.file_extension
+        # Set the output extension
+        resources["output_extension"] = self.file_extension
         return resources
 
+    def _validate_preprocessor(self, nbc, preprocessor):
+        try:
+            nbformat.validate(nbc, relax_add_props=True)
+        except nbformat.ValidationError:
+            self.log.error("Notebook is invalid after preprocessor %s", preprocessor)
+            raise
 
     def _preprocess(self, nb, resources):
         """
@@ -307,18 +326,17 @@ class Exporter(LoggingConfigurable):
 
         # Do a copy.deepcopy first,
         # we are never safe enough with what the preprocessors could do.
-        nbc =  copy.deepcopy(nb)
+        nbc = copy.deepcopy(nb)
         resc = copy.deepcopy(resources)
 
-        #Run each preprocessor on the notebook.  Carry the output along
-        #to each preprocessor
+        # Run each preprocessor on the notebook.  Carry the output along
+        # to each preprocessor
         for preprocessor in self._preprocessors:
             nbc, resc = preprocessor(nbc, resc)
-            try: 
-                nbformat.validate(nbc, relax_add_props=True)
-            except nbformat.ValidationError:
-                self.log.error('Notebook is invalid after preprocessor {}',
-                               preprocessor)
-                raise
+            if not self.optimistic_validation:
+                self._validate_preprocessor(nbc, preprocessor)
+
+        if self.optimistic_validation:
+            self._validate_preprocessor(nbc, preprocessor)
 
         return nbc, resc
