@@ -1,16 +1,19 @@
 # Class base Preprocessors
+# Backwards compatability for imported name
+from nbclient.exceptions import CellExecutionError
+
 from .base import Preprocessor
-from .convertfigures import ConvertFiguresPreprocessor
-from .svg2pdf import SVG2PDFPreprocessor
-from .extractoutput import ExtractOutputPreprocessor
-from .latex import LatexPreprocessor
-from .csshtmlheader import CSSHTMLHeaderPreprocessor
-from .highlightmagics import HighlightMagicsPreprocessor
-from .clearoutput import ClearOutputPreprocessor
-from .execute import ExecutePreprocessor, CellExecutionError
-from .regexremove import RegexRemovePreprocessor
-from .tagremove import TagRemovePreprocessor
 from .clearmetadata import ClearMetadataPreprocessor
+from .clearoutput import ClearOutputPreprocessor
 
 # decorated function Preprocessors
 from .coalescestreams import coalesce_streams
+from .convertfigures import ConvertFiguresPreprocessor
+from .csshtmlheader import CSSHTMLHeaderPreprocessor
+from .execute import ExecutePreprocessor
+from .extractoutput import ExtractOutputPreprocessor
+from .highlightmagics import HighlightMagicsPreprocessor
+from .latex import LatexPreprocessor
+from .regexremove import RegexRemovePreprocessor
+from .svg2pdf import SVG2PDFPreprocessor
+from .tagremove import TagRemovePreprocessor
