@@ -1,4 +1,3 @@
-# encoding: utf-8
 """Tests for utils.io"""
 
 # Copyright (c) Jupyter Development Team.
@@ -6,30 +5,29 @@
 
 import io as stdlib_io
 import sys
-
-import pytest
+from io import StringIO
 
 from ..io import unicode_std_stream
 
-from io import StringIO
 
 def test_UnicodeStdStream():
     # Test wrapping a bytes-level stdout
     stdoutb = stdlib_io.BytesIO()
-    stdout = stdlib_io.TextIOWrapper(stdoutb, encoding='ascii')
+    stdout = stdlib_io.TextIOWrapper(stdoutb, encoding="ascii")
 
     orig_stdout = sys.stdout
     sys.stdout = stdout
     try:
-        sample = u"@łe¶ŧ←"
+        sample = "@łe¶ŧ←"
         unicode_std_stream().write(sample)
 
-        output = stdoutb.getvalue().decode('utf-8')
+        output = stdoutb.getvalue().decode("utf-8")
         assert output == sample
         assert not stdout.closed
     finally:
         sys.stdout = orig_stdout
 
+
 def test_UnicodeStdStream_nowrap():
     # If we replace stdout with a StringIO, it shouldn't get wrapped.
     orig_stdout = sys.stdout
