@@ -12,13 +12,14 @@ from ..utils.base import NbConvertBase
 
 class WriterBase(NbConvertBase):
     """Consumes output from nbconvert export...() methods and writes to a
-    useful location. """
-
-
-    files = List([], help="""
-        List of the files that the notebook references.  Files will be 
-        included with written output.""").tag(config=True)
+    useful location."""
 
+    files = List(
+        [],
+        help="""
+        List of the files that the notebook references.  Files will be
+        included with written output.""",
+    ).tag(config=True)
 
     def __init__(self, config=None, **kw):
         """
@@ -26,7 +27,6 @@ class WriterBase(NbConvertBase):
         """
         super().__init__(config=config, **kw)
 
-
     def write(self, output, resources, **kw):
         """
         Consume and write Jinja output.
